@@ -1,11 +1,11 @@
 class Category(object):
 
     def __init__(self,jsonresponse):
-        self.__code = jsonresponse['code']
-        self.__label = jsonresponse['label']
-        self.__number_of_mentions = jsonresponse['numberOfMentions']
+        self.__code = jsonresponse.get('code')
+        self.__label = jsonresponse.get('label')
+        self.__number_of_mentions = jsonresponse.get('numberOfMentions')
         self.__sub_categories = {}
-        sub_categories = jsonresponse['subCategories']
+        sub_categories = jsonresponse.get('subCategories')
         for s in sub_categories:
             self.__sub_categories.append(Category(s))
 
