@@ -2,15 +2,15 @@
 class Entity(object):
 
     def __init__(self, jsonresponse):
-        self.__uuid = jsonresponse['uuid']
-        self.__mention_number = jsonresponse['mentionNumber']
-        self.__opinion_index = jsonresponse['opinionIndex']
-        self.__name = jsonresponse['name']
-        self.__english_name = jsonresponse['englishName']
-        self.__label_id = jsonresponse['labelId']
-        self.__type = jsonresponse['type']
-        self.__sentences = jsonresponse['sentences']
-        self.__recognized_synonym = jsonresponse['recognizedSynonym']
+        self.__uuid = jsonresponse.get('uuid')
+        self.__mention_number = jsonresponse.get('mentionNumber')
+        self.__opinion_index = jsonresponse.get('opinionIndex')
+        self.__name = jsonresponse.get('name')
+        self.__english_name = jsonresponse.get('englishName', None)
+        self.__label_id = jsonresponse.get('labelId', None)
+        self.__type = jsonresponse.get('type')
+        self.__sentences = jsonresponse.get('sentences')
+        self.__recognized_synonym = jsonresponse.get('recognizedSynonym', None)
 
     def getUUID(self):
         """
