@@ -14,8 +14,13 @@ class LabelTypes(Enum):
     HR = 'hr'
     PERSON = 'person'
     HASHTAG = 'hashtag'
+    PROFESSION = 'profession'
     CUSTOMLABEL = 'custom_label'
 
+class TextSplitType(Enum):
+    SUBSENTENCE = 'SUBSENTENCE'
+    SENTENCE = 'SENTENCE'
+    PARAGRAPH = 'PARAGRAPH'
 
 class PhraseTypes(Enum):
     POSITIVE = 'pos_phrase'
