@@ -3,13 +3,13 @@
 class Sentence(object):
 
     def __init__(self, jsonresponse):
-        self.__uuid = jsonresponse['uuid']
-        self.__position = jsonresponse['position']
-        self.__html_formatted_sentence = jsonresponse['htmlFormattedSentence']
-        self.__contains_keyword = jsonresponse['containsKeyword']
-        self.__entities = jsonresponse['entities']
-        self.__opinionIndex = jsonresponse['opinionIndex']
-        self.__sentence = jsonresponse['sentence']
+        self.__uuid = jsonresponse.get('uuid')
+        self.__position = jsonresponse.get('position')
+        self.__html_formatted_sentence = jsonresponse.get('htmlFormattedSentence')
+        self.__contains_keyword = jsonresponse.get('containsKeyword')
+        self.__entities = jsonresponse.get('entities')
+        self.__opinionIndex = jsonresponse.get('opinionIndex')
+        self.__sentence = jsonresponse.get('sentence')
 
     def getUUID(self):
         '''
